Learn R Programming

TanB (version 0.1)

stanb: The survival function of the Tanget Burr Type XII probability distribution.

Description

The survival function of the Tanget Burr Type XII probability distribution.

Usage

stanb(x, c, k, s)

Arguments

x
vector of quantiles.
c
C parameter.
k
K parameter.
s
S parameter.

Value

A vector with n observations of the Tanget Burr Type XII distribution.

Examples

Run this code
ptanb(0.5, 1, 1, 1)
ptanb(0.5, 2, 1, 1)

Run the code above in your browser using DataLab